=====================
Introduction to `w7x`
=====================


.. pypi
.. image:: https://img.shields.io/pypi/v/w7x.svg
    :target: https://pypi.python.org/pypi/w7x

.. ci
    .. image:: https://img.shields.io/travis/dboe/w7x.svg
        :target: https://travis-ci.com/dboe/w7x
.. image:: https://git.ipp-hgw.mpg.de/dboe/w7x/badges/master/pipeline.svg
    :target: https://git.ipp-hgw.mpg.de/dboe/w7x/commits/master

.. readthedocs
.. image:: https://readthedocs.org/projects/w7x/badge/?version=latest
    :target: https://w7x.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. pyup crosschecks your dependencies. Github is default, gitlab more complicated: https://pyup.readthedocs.io/en/latest/readme.html#run-your-first-update 
    .. image:: https://pyup.io/repos/github/dboe/w7x/shield.svg
        :target: https://pyup.io/repos/github/dboe/w7x/
        :alt: Updates

.. image:: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white
   :target: https://github.com/pre-commit/pre-commit
   :alt: pre-commit


Wendelstein 7-X tools providing easy acces and error catching for field line tracer, VMEC and EXTENDER web services and much more.


Licensed under the ``MIT License``

Resources
---------

* Source code: https://git.ipp-hgw.mpg.de/dboe/w7x
* Documentation: https://w7x.readthedocs.io
* Pypi: https://pypi.python.org/pypi/w7x


Features
--------

The following features should be highlighted:

* TODO
